@@ -15,7 +15,10 @@
 #'   Ignored if `quietly = TRUE`.
 #' @param minimum_version A character vector, representing the minimum package
 #'   version that is required for each package. Should be of same length as
-#'   `package`. If `NULL`, no check for minimum version is done.
+#'   `package`. If `NULL`, will automatically check the DESCRIPTION file for
+#'   the correct minimum version. If using `minimum_version` with more than one
+#'   package, `NA` should be used instead of `NULL` for packages where a
+#'   specific version is not necessary.
 #' @param ... Currently ignored
 #'
 #' @return If `stop = TRUE`, and `package` is not yet installed, the
@@ -25,9 +28,15 @@
 #' @examplesIf interactive() || identical(Sys.getenv("IN_PKGDOWN"), "true")
 #' \dontrun{
 #' check_if_installed("insight")
-#' try(check_if_installed("nonexistent_package"))
+#' try(check_if_installed("datawizard", stop = FALSE))
+#' try(check_if_installed("rstanarm", stop = FALSE))
+#' try(check_if_installed("nonexistent_package", stop = FALSE))
 #' try(check_if_installed("insight", minimum_version = "99.8.7"))
 #' try(check_if_installed(c("nonexistent", "also_not_here"), stop = FALSE))
+#' try(check_if_installed(c("datawizard", "rstanarm"), stop = FALSE))
+#' try(check_if_installed(c("datawizard", "rstanarm"),
+#'   minimum_version = c(NA, "2.21.1"), stop = FALSE
+#' ))
 #' }
 #' @export
 check_if_installed <- function(package,
@@ -37,9 +46,13 @@ check_if_installed <- function(package,
                                quietly = FALSE,
                                prompt = interactive(),
                                ...) {
-  is_installed <- sapply(package, requireNamespace, quietly = TRUE)
+  is_installed <- vapply(package, requireNamespace, quietly = TRUE, FUN.VALUE = TRUE)
   what_is_wrong <- what_you_can_do <- NULL
 
+  if (is.null(minimum_version)) {
+    minimum_version <- .get_dep_version(dep = package)
+  }
+
   ## Test
   if (!all(is_installed)) {
     # only keep not-installed packages
@@ -55,12 +68,21 @@ check_if_installed <- function(package,
     what_you_can_do <- sprintf(
       "Please install %s by running `install.packages(%s)`.",
       if (length(package) > 1L) "them" else "it",
-      toString(sprintf("`%s`", package))
+      toString(sprintf("\"%s\"", package))
     )
   } else if (!is.null(minimum_version)) {
-    needs_update <- utils::packageVersion(package) < package_version(minimum_version)
+    needs_update <- unlist(Map(function(p, m) {
+      if (is.na(m)) {
+        FALSE
+      } else {
+        utils::packageVersion(p) < package_version(m)
+      }
+    }, package, minimum_version))
 
     if (any(needs_update)) {
+      # set is_installed to FALSE for packages that fail minimum version check
+      is_installed[needs_update] <- FALSE
+
       # only keep not-up-to-date packages
       package <- package[needs_update]
       minimum_version <- minimum_version[needs_update]
@@ -78,7 +100,7 @@ check_if_installed <- function(package,
       what_you_can_do <- sprintf(
         "Please update %s by running `install.packages(%s)`.",
         if (length(package) > 1L) "them" else "it",
-        toString(sprintf("`%s`", package))
+        toString(sprintf("\"%s\"", package))
       )
     }
   }
@@ -128,3 +150,18 @@ print.check_if_installed <- function(x, ...) {
     print_color(paste0("- ", names(x)[!x], collapse = "\n"), "red")
   }
 }
+
+.get_dep_version <- function(dep, pkg = utils::packageName()) {
+  suggests_field <- utils::packageDescription(pkg, fields = "Suggests")
+  suggests_list <- unlist(strsplit(suggests_field, ",", fixed = TRUE))
+  out <- lapply(dep, function(x) {
+    dep_string <- grep(x, suggests_list, value = TRUE, fixed = TRUE)
+    dep_string <- dep_string[which.min(nchar(dep_string))]
+    dep_string <- unlist(strsplit(dep_string, ">", fixed = TRUE))
+    gsub("[^0-9.]+", "", dep_string[2])
+  })
+  if (all(is.na(out))) {
+    out <- NULL
+  }
+  unlist(out)
+}
