@@ -190,14 +190,14 @@ find_parameters.marginaleffects <- function(x, flatten = FALSE, ...) {
   # Recover dataframe
   excl <- c(
     "rowid", "type", "estimate", "std.error", "contrast", "term", "dydx",
-    "statistic", "p.value", "conf.low", "conf.high", "predicted_hi",
+    "statistic", "p.value", "s.value", "conf.low", "conf.high", "predicted_hi",
     "predicted_lo", "predicted", "eps", "marginaleffects_eps"
   )
 
   params <- x[!names(x) %in% excl]
 
   # Remove fixed variables
-  params <- params[sapply(params, function(x) length(unique(x)) > 1)]
+  params <- params[vapply(params, function(x) length(unique(x)) > 1, TRUE)]
   # Transform to list
   out <- list(marginaleffects = names(params))
 
