@@ -6,24 +6,29 @@
 #'   or arithmetic expressions like `log()`, `I()`, `as.factor()` etc. are
 #'   preserved.
 #'
+#' @param as_term_labels Logical, if `TRUE`, extracts model formula and tries to
+#'   access the `"term.labels"` attribute. This should better mimic the `terms()`
+#'   behaviour even for those models that do not have such a method, but may be
+#'   insufficient, e.g. for mixed models.
 #' @inheritParams find_formula
 #' @inheritParams find_predictors
 #'
 #' @return A list with (depending on the model) following elements (character
-#'    vectors):
-#'    \itemize{
-#'      \item `response`, the name of the response variable
-#'      \item `conditional`, the names of the predictor variables from the *conditional* model (as opposed to the zero-inflated part of a model)
-#'      \item `random`, the names of the random effects (grouping factors)
-#'      \item `zero_inflated`, the names of the predictor variables from the *zero-inflated* part of the model
-#'      \item `zero_inflated_random`, the names of the random effects (grouping factors)
-#'      \item `dispersion`, the name of the dispersion terms
-#'      \item `instruments`, the names of instrumental variables
-#'    }
-#'    Returns `NULL` if no terms could be found (for instance, due to
-#'    problems in accessing the formula).
+#' vectors):
 #'
-#' @note The difference to [find_variables()] is that `find_terms()`
+#' - `response`, the name of the response variable
+#' - `conditional`, the names of the predictor variables from the *conditional*
+#'    model (as opposed to the zero-inflated part of a model)
+#' - `random`, the names of the random effects (grouping factors)
+#' - `zero_inflated`, the names of the predictor variables from the *zero-inflated* part of the model
+#' - `zero_inflated_random`, the names of the random effects (grouping factors)
+#' - `dispersion`, the name of the dispersion terms
+#' - `instruments`, the names of instrumental variables
+#'
+#' Returns `NULL` if no terms could be found (for instance, due to
+#' problems in accessing the formula).
+#'
+#' @note The difference to [`find_variables()`] is that `find_terms()`
 #'   may return a variable multiple times in case of multiple transformations
 #'   (see examples below), while `find_variables()` returns each variable
 #'   name only once.
@@ -38,19 +43,29 @@
 #'
 #'   find_terms(m)
 #' }
+#'
+#' # sometimes, it is necessary to retrieve terms from "term.labels" attribute
+#' m <- lm(mpg ~ hp * (am + cyl), data = mtcars)
+#' find_terms(m, as_term_labels = TRUE)
 #' @export
-find_terms <- function(x, flatten = FALSE, verbose = TRUE, ...) {
+find_terms <- function(x, ...) {
   UseMethod("find_terms")
 }
 
+#' @rdname find_terms
 #' @export
-find_terms.default <- function(x, flatten = FALSE, verbose = TRUE, ...) {
+find_terms.default <- function(x, flatten = FALSE, as_term_labels = FALSE, verbose = TRUE, ...) {
   f <- find_formula(x, verbose = verbose)
 
   if (is.null(f)) {
     return(NULL)
   }
 
+  # mimics original "terms()" behaviour, leads to slightly different results
+  if (isTRUE(as_term_labels)) {
+    return(lapply(f, function(i) attr(stats::terms(i), "term.labels")))
+  }
+
   resp <- find_response(x, verbose = FALSE)
 
   if (is_multivariate(f) || isTRUE(attributes(f)$two_stage)) {
