@@ -112,37 +112,38 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
 
   # convert broom-style to easystats
   # styler: off
-  cn[cn == "term"]         <- "Parameter"
-  cn[cn == "estimate"]     <- "Coefficient"
-  cn[cn == "std.error"]    <- "SE"
-  cn[cn == "std.dev"]      <- "SD"
-  cn[cn == "p.value"]      <- "p"
-  cn[cn == "bayes.factor"] <- "BF"
-  cn[cn == "component"]    <- "Component"
-  cn[cn == "effect"]       <- "Effects"
-  cn[cn == "predicted"]    <- "Predicted"
-  cn[cn == "response"]     <- "Response"
-  cn[cn == "statistic"]    <- "Statistic"
-  cn[cn == "conf.low"]     <- "CI_low"
-  cn[cn == "conf.high"]    <- "CI_high"
-  cn[cn == "conf.level"]   <- "CI"
-  cn[cn == "conf.method"]  <- "CI_method"
-  cn[cn == "n.obs"]        <- "n_Obs"
-  cn[cn == "n"]            <- "n_Obs"
-  cn[cn == "type"]         <- "Type"
+  cn[cn == "term"]           <- "Parameter"
+  cn[cn == "estimate"]       <- "Coefficient"
+  cn[cn == "std.error"]      <- "SE"
+  cn[cn == "std.dev"]        <- "SD"
+  cn[cn == "p.value"]        <- "p"
+  cn[cn == "bayes.factor"]   <- "BF"
+  cn[cn == "component"]      <- "Component"
+  cn[cn == "effect"]         <- "Effects"
+  cn[cn == "predicted"]      <- "Predicted"
+  cn[cn == "response"]       <- "Response"
+  cn[cn == "response.level"] <- "Response_Level"
+  cn[cn == "statistic"]      <- "Statistic"
+  cn[cn == "conf.low"]       <- "CI_low"
+  cn[cn == "conf.high"]      <- "CI_high"
+  cn[cn == "conf.level"]     <- "CI"
+  cn[cn == "conf.method"]    <- "CI_method"
+  cn[cn == "n.obs"]          <- "n_Obs"
+  cn[cn == "n"]              <- "n_Obs"
+  cn[cn == "type"]           <- "Type"
   # marginaleffects
-  cn[cn == "value"]        <- "Level"
+  cn[cn == "value"]          <- "Level"
   # anova
-  cn[cn == "sumsq"]        <- "Sum_Squares"
-  cn[cn == "meansq"]       <- "Mean_Square"
-  cn[cn == "Resid..Dev"]   <- "Deviance_error"
+  cn[cn == "sumsq"]          <- "Sum_Squares"
+  cn[cn == "meansq"]         <- "Mean_Square"
+  cn[cn == "Resid..Dev"]     <- "Deviance_error"
   # convert classic summary
-  cn[cn == "Estimate"]     <- "Coefficient"
-  cn[cn == "Std. Error"]   <- "SE"
-  cn[cn == "t value"]      <- "Statistic"
-  cn[cn == "z value"]      <- "Statistic"
-  cn[cn == "Pr(>|t|)"]     <- "p"
-  cn[cn == "Pr(>|z|)"]     <- "p"
+  cn[cn == "Estimate"]       <- "Coefficient"
+  cn[cn == "Std. Error"]     <- "SE"
+  cn[cn == "t value"]        <- "Statistic"
+  cn[cn == "z value"]        <- "Statistic"
+  cn[cn == "Pr(>|t|)"]       <- "p"
+  cn[cn == "Pr(>|z|)"]       <- "p"
   # styler: on
 
   cn
@@ -162,6 +163,7 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
   cn[cn == "Component"]      <- "component"
   cn[cn == "Effects"]        <- "effect"
   cn[cn == "Response"]       <- "response"
+  cn[cn == "Response_Level"] <- "response.level"
   cn[cn == "CI"]             <- "conf.level"
   cn[cn == "df_error"]       <- "df.error"
   cn[cn == "df_residual"]    <- "df.residual"
@@ -185,8 +187,8 @@ standardize_names.parameters_distribution <- standardize_names.parameters_model
   cn[cn %in% c("Dxy", "rho", "r", "tau")] <- "estimate"
 
   # for glance
-  cn[cn %in% c("R2")] <- "r.squared"
-  cn[cn %in% c("R2_adjusted")] <- "adj.r.squared"
+  cn[cn == "R2"] <- "r.squared"
+  cn[cn == "R2_adjusted"] <- "adj.r.squared"
 
   if (("Difference" %in% cn) && !("estimate" %in% cn)) {
     cn[cn == "Difference"] <- "estimate"
